@@ -13,12 +13,6 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-from . import auth
-from . import dbapi
-from . import execution
 from . import client
-from . import constants
-from . import exceptions
-from . import logging
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
